==> libreoffice-still-debug-25.2.6-4-x86_64.pkg.tar.zst: usr/src/debug/libreoffice-still/libreoffice-25.2.6.2/workdir/UnpackedTarball/skia/tools/window/VulkanWindowContext.h <==
/*
 * Copyright 2023 Google LLC
 *
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */
#ifndef VulkanWindowContext_DEFINED
#define VulkanWindowContext_DEFINED

#include "include/core/SkTypes.h"

#include "include/gpu/vk/VulkanBackendContext.h"
#include "tools/gpu/vk/VkTestUtils.h"
#include "tools/window/WindowContext.h"

#include <cassert>

class GrRenderTarget;

namespace skgpu { struct VulkanInterface; }

namespace skwindow::internal {

class SK_API VulkanWindowContext : public WindowContext {
public:
    ~VulkanWindowContext() override;

    static GrDirectContext* getSharedGrDirectContext() { return fGlobalShared ? fGlobalShared->fContext.get() : nullptr; }

    sk_sp<SkSurface> getBackbufferSurface() override;

    bool isValid() override { return fSurface != VK_NULL_HANDLE; }

    void resize(int w, int h) override {
        this->createSwapchain(w, h, fDisplayParams);
    }

    void setDisplayParams(const DisplayParams& params) override {
        this->destroyContext();
        fDisplayParams = params;
        this->initializeContext();
    }

    /** Platform specific function that creates a VkSurfaceKHR for a window */
    using CreateVkSurfaceFn = std::function<VkSurfaceKHR(VkInstance)>;
    /** Platform specific function that determines whether presentation will succeed. */
    using CanPresentFn = sk_gpu_test::CanPresentFn;

    VulkanWindowContext(const DisplayParams&, CreateVkSurfaceFn, CanPresentFn,
                        PFN_vkGetInstanceProcAddr);

    static const VkPhysicalDeviceProperties& getPhysDeviceProperties() {
        assert( fGlobalShared != nullptr );
        return fGlobalShared->physDeviceProperties;
    }

private:
    void initializeContext();
    void destroyContext();
    static void checkDestroyShared();

    struct BackbufferInfo {
        uint32_t        fImageIndex;          // image this is associated with
        VkSemaphore     fRenderSemaphore;     // we wait on this for rendering to be done
    };

    BackbufferInfo* getAvailableBackbuffer();
    bool createSwapchain(int width, int height, const DisplayParams& params);
    bool createBuffers(VkFormat format, VkImageUsageFlags, SkColorType colorType, VkSharingMode);
    void destroyBuffers();
    void onSwapBuffers(const SkIRect* rect = nullptr) override;

    // Create functions
    CreateVkSurfaceFn fCreateVkSurfaceFn;
    CanPresentFn      fCanPresentFn;

    PFN_vkGetInstanceProcAddr fGetInstanceProcAddr = nullptr;

    // WSI interface functions
    PFN_vkDestroySurfaceKHR fDestroySurfaceKHR = nullptr;
    PFN_vkGetPhysicalDeviceSurfaceSupportKHR fGetPhysicalDeviceSurfaceSupportKHR = nullptr;
    PFN_vkGetPhysicalDeviceSurfaceCapabilitiesKHR fGetPhysicalDeviceSurfaceCapabilitiesKHR =nullptr;
    PFN_vkGetPhysicalDeviceSurfaceFormatsKHR fGetPhysicalDeviceSurfaceFormatsKHR = nullptr;
    PFN_vkGetPhysicalDeviceSurfacePresentModesKHR fGetPhysicalDeviceSurfacePresentModesKHR =nullptr;

    PFN_vkCreateSwapchainKHR fCreateSwapchainKHR = nullptr;
    PFN_vkDestroySwapchainKHR fDestroySwapchainKHR = nullptr;
    PFN_vkGetSwapchainImagesKHR fGetSwapchainImagesKHR = nullptr;
    PFN_vkAcquireNextImageKHR fAcquireNextImageKHR = nullptr;
    PFN_vkQueuePresentKHR fQueuePresentKHR = nullptr;

    PFN_vkDeviceWaitIdle fDeviceWaitIdle = nullptr;
    PFN_vkQueueWaitIdle fQueueWaitIdle = nullptr;
    PFN_vkGetDeviceQueue fGetDeviceQueue = nullptr;

    // We need to use just one GrDirectContext, so share all the relevant data.
    struct Shared : public SkRefCnt
    {
    PFN_vkDestroyInstance fDestroyInstance = nullptr;
    PFN_vkDestroyDevice fDestroyDevice = nullptr;
    PFN_vkDestroyDebugReportCallbackEXT fDestroyDebugReportCallbackEXT = nullptr;

    VkInstance fInstance = VK_NULL_HANDLE;
    VkPhysicalDevice fPhysicalDevice = VK_NULL_HANDLE;
    VkDevice fDevice = VK_NULL_HANDLE;
    VkDebugReportCallbackEXT fDebugCallback = VK_NULL_HANDLE;

    sk_sp<const skgpu::VulkanInterface> fInterface;

    // Original code had this as a function-local variable, but that seems wrong.
    // It should exist as long as the context exists.
    VkPhysicalDeviceFeatures2 features;

    // Store this to make it accessible.
    VkPhysicalDeviceProperties physDeviceProperties;

    skgpu::VulkanBackendContext backendContext;

    uint32_t          fGraphicsQueueIndex;
    VkQueue           fGraphicsQueue;
    uint32_t          fPresentQueueIndex;

    sk_sp<GrDirectContext> fContext;
    };

    sk_sp<Shared> fShared;

    static sk_sp<Shared> fGlobalShared;

    VkSurfaceKHR      fSurface;
    VkSwapchainKHR    fSwapchain;
    VkQueue           fPresentQueue;

    uint32_t               fImageCount;
    VkImage*               fImages;         // images in the swapchain
    VkImageLayout*         fImageLayouts;   // layouts of these images when not color attachment
    sk_sp<SkSurface>*      fSurfaces;       // surfaces client renders to (may not be based on rts)
    BackbufferInfo*        fBackbuffers;
    uint32_t               fCurrentBackbufferIndex;
};

}  // namespace skwindow::internal

#endif

==> libreoffice-still-debug-25.8.5-2-x86_64.pkg.tar.zst: usr/src/debug/libreoffice-still/libreoffice-25.8.5.2/workdir/UnpackedTarball/skia/tools/window/VulkanWindowContext.h <==
/*
 * Copyright 2023 Google LLC
 *
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */
#ifndef VulkanWindowContext_DEFINED
#define VulkanWindowContext_DEFINED

#include "include/core/SkTypes.h"

#include "include/gpu/vk/VulkanBackendContext.h"
#include "tools/gpu/vk/VkTestUtils.h"
#include "tools/window/WindowContext.h"

#include <cassert>

class GrRenderTarget;

namespace skgpu { struct VulkanInterface; }

namespace skwindow::internal {

class SK_API VulkanWindowContext : public WindowContext {
public:
    ~VulkanWindowContext() override;

    static GrDirectContext* getSharedGrDirectContext() { return fGlobalShared ? fGlobalShared->fContext.get() : nullptr; }

    sk_sp<SkSurface> getBackbufferSurface() override;

    bool isValid() override { return fSurface != VK_NULL_HANDLE; }

    void resize(int w, int h) override { this->createSwapchain(w, h); }

    void setDisplayParams(std::unique_ptr<const DisplayParams> params) override {
        this->destroyContext();
        fDisplayParams = std::move(params);
        this->initializeContext();
    }

    /** Platform specific function that creates a VkSurfaceKHR for a window */
    using CreateVkSurfaceFn = std::function<VkSurfaceKHR(VkInstance)>;
    /** Platform specific function that determines whether presentation will succeed. */
    using CanPresentFn = sk_gpu_test::CanPresentFn;

    VulkanWindowContext(std::unique_ptr<const DisplayParams>,
                        CreateVkSurfaceFn,
                        CanPresentFn,
                        PFN_vkGetInstanceProcAddr);

    static const VkPhysicalDeviceProperties& getPhysDeviceProperties() {
        assert( fGlobalShared != nullptr );
        return fGlobalShared->physDeviceProperties;
    }

private:
    void initializeContext();
    void destroyContext();
    static void checkDestroyShared();

    struct BackbufferInfo {
        uint32_t        fImageIndex;          // image this is associated with
        VkSemaphore     fRenderSemaphore;     // we wait on this for rendering to be done
    };

    BackbufferInfo* getAvailableBackbuffer();
    bool createSwapchain(int width, int height);
    bool createBuffers(VkFormat format, VkImageUsageFlags, SkColorType colorType, VkSharingMode);
    void destroyBuffers();
    void onSwapBuffers(const SkIRect* rect = nullptr) override;

    // Create functions
    CreateVkSurfaceFn fCreateVkSurfaceFn;
    CanPresentFn      fCanPresentFn;

    PFN_vkGetInstanceProcAddr fGetInstanceProcAddr = nullptr;

    // WSI interface functions
    PFN_vkDestroySurfaceKHR fDestroySurfaceKHR = nullptr;
    PFN_vkGetPhysicalDeviceSurfaceSupportKHR fGetPhysicalDeviceSurfaceSupportKHR = nullptr;
    PFN_vkGetPhysicalDeviceSurfaceCapabilitiesKHR fGetPhysicalDeviceSurfaceCapabilitiesKHR =nullptr;
    PFN_vkGetPhysicalDeviceSurfaceFormatsKHR fGetPhysicalDeviceSurfaceFormatsKHR = nullptr;
    PFN_vkGetPhysicalDeviceSurfacePresentModesKHR fGetPhysicalDeviceSurfacePresentModesKHR =nullptr;

    PFN_vkCreateSwapchainKHR fCreateSwapchainKHR = nullptr;
    PFN_vkDestroySwapchainKHR fDestroySwapchainKHR = nullptr;
    PFN_vkGetSwapchainImagesKHR fGetSwapchainImagesKHR = nullptr;
    PFN_vkAcquireNextImageKHR fAcquireNextImageKHR = nullptr;
    PFN_vkQueuePresentKHR fQueuePresentKHR = nullptr;

    PFN_vkDeviceWaitIdle fDeviceWaitIdle = nullptr;
    PFN_vkQueueWaitIdle fQueueWaitIdle = nullptr;
    PFN_vkGetDeviceQueue fGetDeviceQueue = nullptr;

    // We need to use just one GrDirectContext, so share all the relevant data.
    struct Shared : public SkRefCnt
    {
    PFN_vkDestroyInstance fDestroyInstance = nullptr;
    PFN_vkDestroyDevice fDestroyDevice = nullptr;
    PFN_vkDestroyDebugReportCallbackEXT fDestroyDebugReportCallbackEXT = nullptr;

    VkInstance fInstance = VK_NULL_HANDLE;
    VkPhysicalDevice fPhysicalDevice = VK_NULL_HANDLE;
    VkDevice fDevice = VK_NULL_HANDLE;
    VkDebugReportCallbackEXT fDebugCallback = VK_NULL_HANDLE;

    sk_sp<const skgpu::VulkanInterface> fInterface;

    // Original code had this as a function-local variable, but that seems wrong.
    // It should exist as long as the context exists.
    VkPhysicalDeviceFeatures2 features;

    // Store this to make it accessible.
    VkPhysicalDeviceProperties physDeviceProperties;

    skgpu::VulkanBackendContext backendContext;

    uint32_t          fGraphicsQueueIndex;
    VkQueue           fGraphicsQueue;
    uint32_t          fPresentQueueIndex;

    sk_sp<GrDirectContext> fContext;
    };

    sk_sp<Shared> fShared;

    static sk_sp<Shared> fGlobalShared;

    VkSurfaceKHR      fSurface;
    VkSwapchainKHR    fSwapchain;
    VkQueue           fPresentQueue;

    uint32_t               fImageCount;
    VkImage*               fImages;         // images in the swapchain
    VkImageLayout*         fImageLayouts;   // layouts of these images when not color attachment
    sk_sp<SkSurface>*      fSurfaces;       // surfaces client renders to (may not be based on rts)
    BackbufferInfo*        fBackbuffers;
    uint32_t               fCurrentBackbufferIndex;
};

}  // namespace skwindow::internal

#endif
